Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 32 fields pub AES_HASH: AesHash, pub ANAMISC_BIF: AnamiscBif, pub CACHE: Cache, pub CHARGER: Charger, pub CHG_DET: ChgDet, pub CRG_AUD: CrgAud, pub CRG_CTRL: CrgCtrl, pub CRG_GPU: CrgGpu, pub CRG_SNC: CrgSnc, pub CRG_SYS: CrgSys, pub CRG_TOP: CrgTop, pub CRG_VSYS: CrgVsys, pub CRG_XTAL: CrgXtal, pub DCACHE: Dcache, pub DCDC: Dcdc, pub DCDC_BOOST: DcdcBoost, pub DMA: Dma, pub DSI2: Dsi2, pub DSIDPHY_REG: DsidphyReg, pub EMMC: Emmc, pub GPADC: Gpadc, pub GPIO: Gpio, pub GPREG: Gpreg, pub GPU_CORE: GpuCore, pub GPU_REG: GpuReg, pub I2C: I2C, pub I2C2: I2C2, pub I2C3: I2C3, pub I3C: I3C, pub LCDC: Lcdc, pub MEMCTRL: Memctrl, pub OQSPIF: Oqspif,
}
Required for compatibility with RTIC and other frameworks

Fields

AES_HASH: AesHashANAMISC_BIF: AnamiscBifCACHE: CacheCHARGER: ChargerCHG_DET: ChgDetCRG_AUD: CrgAudCRG_CTRL: CrgCtrlCRG_GPU: CrgGpuCRG_SNC: CrgSncCRG_SYS: CrgSysCRG_TOP: CrgTopCRG_VSYS: CrgVsysCRG_XTAL: CrgXtalDCACHE: DcacheDCDC: DcdcDCDC_BOOST: DcdcBoostDMA: DmaDSI2: Dsi2DSIDPHY_REG: DsidphyRegEMMC: EmmcGPADC: GpadcGPIO: GpioGPREG: GpregGPU_CORE: GpuCoreGPU_REG: GpuRegI2C: I2CI2C2: I2C2I2C3: I2C3I3C: I3CLCDC: LcdcMEMCTRL: MemctrlOQSPIF: Oqspif

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks